IndianDateFormatter class

Formatter for Indian date formats and fiscal year utilities.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

financialQuarter(DateTime date) String
Returns the financial quarter for a given date.
fiscalYear(DateTime date) String
Returns the Indian fiscal year for a given date.
format(DateTime date) String
Formats a date in Indian format: "16 April 2026"
formatHindi(DateTime date) String
Formats a date in Hindi: "१६ अप्रैल २०२६"
hindiMonthName(DateTime date) String
Returns the Hindi month name for a given date.
hinduMonthName(DateTime date) String
Returns the approximate Hindu calendar month name.
isFiscalYearStart(DateTime date) bool
Checks if a date is the start of the fiscal year (April 1).
toDevanagari(DateTime date) String
Formats a date in Devanagari numerals: "१६/०४/२०२६"
toHindiNumerals(String number) String
Converts a numeric string to Hindi numerals.