IndianState class
Represents an Indian state or union territory.
Constructors
Properties
- capital → String
-
Capital city
final
- code → String
-
Two-letter state code
final
- gstCode → int
-
GST state code (numeric)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hindiName → String
-
Hindi name
final
- isUT → bool
-
Whether this is a Union Territory
final
- name → String
-
State/UT name
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited